@@ -18,7 +18,7 @@ fi
 
 if [ $( ${UNZIP} -l "${Z}" | \
   tail -n +4 |head -n -2 | \
-  egrep -i '[.](bat|btm|cmd|com|cpl|dat|dll|exe|lnk|msi|pif|prf|reg|scr|vb|vbs|url)$' | \
+  egrep -i '[.](bat|btm|cmd|com|cpl|dat|dll|exe|lnk|msi|pif|prf|reg|scr|vb|vbs|url|jar)$' | \
   wc -l ) -gt 0 ]
 then
  exit 1
